==> nextcloud-app-calendar-1%3A1.7.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/et_EE.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalender",
    "%s has published the calendar »%s«" : "%s avaldas kalendri »%s«",
    "Hello," : "Tere,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Tahtsime Sind informeerida, et %s on avaldanud kalendri»%s«.",
    "Open »%s«" : "Ava »%s«",
    "Cheers!" : "Tervist!",
    "Recipient" : "Saaja",
    "Too many redirects. Aborting ..." : "Liiga palju ümbersuunamisi. Katkestamine ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Kaugserver ei andnud juurdepääsu kalendrile (HTTP {%s} viga)",
    "Error connecting to remote server" : "Kaugserveriga ühendumise tõrge",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Viga kaugserveri vahendite pärimisel. See võib seotud olla sertifikaatide mittesobivusega",
    "Error requesting resource on remote server" : "Viga kaugserveri vahendite pärimisel",
    "Individual" : "Individuaalne",
    "Group" : "Grupp",
    "Resource" : "Ressurss",
    "Room" : "Ruum",
    "Unknown" : "Tundmatu",
    "Required" : "Kohustuslik",
    "Optional" : "Valikuline",
    "Does not attend" : "Ei võta osa",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Asud tundmatus ajavööndis ({tz}), kasutusel UTC",
    "Please create a calendar first." : "Palun loo esmalt kalender.",
    "New event" : "Uus sündmus",
    "CalDAV address for clients" : "CalDAV aadress klientidele",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Mõned sündmused selles kalendris on katki. Palun kontrolli JS konsooli, et rohkem infot saada.",
    "Share Calendar" : "Jaga kalendrit",
    "Shared" : "Jagatud",
    "WebDAV address for subscriptions" : "WebDAV aadress tellimiseks",
    "group" : "grupp",
    "Details" : "Üksikasjad",
    "Attendees" : "Osalejad",
    "Reminders" : "Meelespead",
    "Repeating" : "Kordamine",
    "When shared show full event" : "Kui on jagatud, siis näita kogu sündmust",
    "When shared show only busy" : "Kui on jagatud, siis näita ainult, kas on hõivatud",
    "When shared hide this event" : "Kui on jagatud, siis peida see sündmus",
    "Confirmed" : "Kinnitatud",
    "Tentative" : "Esialgne",
    "Cancelled" : "Tühistatud",
    "Please add a title." : "Palun lisa pealkiri.",
    "Please select a calendar." : "Palun vali kalender.",
    "The event can not end before it starts." : "Sündmus ei saa lõppeda enne, kui see algab",
    "Global" : "Üldine",
    "None" : "Pole",
    "Every day" : "Iga päev",
    "Every week" : "Iga nädal",
    "Every month" : "Iga kuu",
    "Every year" : "Iga aasta",
    "never" : "mitte kunagi",
    "after" : "pärast",
    "How about getting started by importing some calendars?" : "Kuidas oleks, kui alustaks mõne kalendri importimisega?",
    "At time of event" : "Sündmuse aeg",
    "5 minutes before" : "5 minutit enne",
    "10 minutes before" : "10 minutit enne",
    "15 minutes before" : "15 minutit enne",
    "30 minutes before" : "30 minutit enne",
    "1 hour before" : "1 tund enne",
    "2 hours before" : "2 tundi enne",
    "Custom" : "Kohandatud",
    "Audio" : "Helid",
    "Email" : "Epost",
    "Pop-up" : "Hüpikaken",
    "sec" : "sek",
    "min" : "min",
    "hours" : "tundi",
    "days" : "päeva",
    "week" : "nädal",
    "before" : "enne",
    "start" : "algus",
    "end" : "lõpp",
    "Editing reminders of unknown type not supported." : "Tundmatud tüüpi meeldetuletuste muutmine pole toetatud.",
    "Week {number} of {year}" : "Nädal nr. {number} aastas {year}",
    "Successfully imported {imported} objects" : "Edukalt imporditud {imported} objektid",
    "Imported {imported} out of {all}, skipped one duplicate" : "Imporditud {imported}  koguhulgast {all}, välja jäetud üks duplikaat",
    "Imported {imported} out of {all}, one failure" : "Imporditud {imported}  koguhulgast {all}, üks ebaõnnestus",
    "Imported {imported} out of {all}, {errors} failures" : "Imporditud {imported}  koguhulgast {all}, ebaõnnestus {errors}",
    "Imported {imported} out of {all}, skipped {duplicates} duplicates" : "Imporditud {imported}  koguhulgast {all}, välja jäetud {duplicates} duplikaati",
    "Imported {imported} out of {all}, {errors} failures, skipped {duplicates} duplicates" : "Imporditud {imported}  koguhulgast {all}, ebaõnnestus {errors}, välja jäetud  {duplicates} duplikaati",
    "{type} at {time}" : "{type} kell {time}",
    "{calendar} shared by {owner}" : "{calendar} jagas {owner}",
    "Please enter a valid WebCal-URL" : "Palun sisesta korrektne WebCal-URL",
    "Title of the Event" : "Sündmuse pealkiri",
    "Starts" : "Algab",
    "Ends" : "Lõpeb",
    "All day Event" : "Kogu päeva sündmus",
    "Delete" : "Kustuta",
    "Cancel" : "Loobu",
    "More ..." : "Veel ...",
    "Create" : "Lisa",
    "Update" : "Uuenda",
    "Close" : "Sulge",
    "Location" : "Asukoht",
    "Description" : "Kirjeldus",
    "Event status" : "Sündmuse staatus",
    "Visibility when sharing" : "Nähtavus jagamisel",
    "Export" : "Ekspordi",
    "%s has published the calendar %s" : "%s on avaldanud kalendri %s",
    "Click on the link below to access it" : "Ligipääsuks vajuta allolevale lingile",
    "Day" : "Päev",
    "Week" : "Nädal",
    "Month" : "Kuu",
    "Today" : "Täna",
    "More" : "Rohkem",
    "Edit" : "Muuda",
    "Link" : "Link",
    "iCal link" : "iCal link",
    "Download" : "Lae alla",
    "can edit" : "saab muuta",
    "Share link" : "Jaga link",
    "Public access" : "Avalik ligipääs",
    "Email link to person" : "Saada link e-postiga",
    "Send" : "Saada",
    "New Calendar" : "Uus kalender",
    "Name" : "Nimi",
    "New Subscription" : "Uus tellimus",
    "Go back" : "Mine tagasi",
    "Go forward" : "Mine edasi",
    "Calendar does not exist" : "Kalendrit pole olemas",
    "Maybe you got a wrong link or the calendar was unshared?" : "Võibolla said vale lingi või kalendri jagamine lõpetati?",
    "Edit event" : "Muuda sündmust",
    "Delete Event" : "Kustuta sündmus",
    "Save Event" : "Salvesta sündmus",
    "Time" : "Aeg",
    "Type" : "Tüüp",
    "Relative" : "Suhteline",
    "Absolute" : "Absoluutne",
    "Repeat" : "Korda",
    "times every" : "korda iga",
    "Add" : "Lisa",
    "Email address of attendee" : "Osaleja e-posti aadress",
    "Please add your email address in the personal settings in order to add attendees." : "Palun määra e-posti aadress oma isiklikes sätetes, et osalejaid lisada.",
    "from" : "alates",
    "to" : "kuni",
    "Reset repeating rule" : "Nulli kordamise reegel",
    "Repeat every ..." : "Korda iga ...",
    "end repeat ..." : "lõpeta kordamine",
    "times" : "korda",
    "Import Calendars" : "Impordi kalendreid",
    "Import canceled" : "Importimine on tühistatud",
    "Analyzing calendar" : "Kalendri analüüsimine",
    "The file contains objects incompatible with the selected calendar" : "See file sisaldab objekte, mis ei ole valitud kalendriga ühilduvad",
    "New calendar" : "Uus kalender",
    "File is empty" : "Fail on tühi",
    "Import scheduled" : "Importimine on ajastatud",
    "%s shared the calendar <strong>%s</strong> with you" : "%s jagas sinuga kalendrit <strong>%s</strong>",
    "Embed" : "Manusta",
    "Iframe to integrate" : "Iframe integreerimiseks",
    "Publish URL" : "Avalikusta URL",
    "Settings & import" : "Sätted & importimine",
    "Import calendar" : "Impordi kalender",
    "No Calendars selected for import" : "Pole valitud kalendreid, mida importida",
    "Skip simple event editor" : "Jäta lihtne sündmuse redaktor vahele",
    "Show week numbers" : "Näita nädalanumberid",
    "Primary CalDAV address" : "Primaarne CalDAV aadress",
    "Subscribe" : "Telli"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1%3A2.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/et_EE.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalender",
    "%s has published the calendar »%s«" : "%s avaldas kalendri »%s«",
    "Hello," : "Tere,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Tahtsime Sind informeerida, et %s on avaldanud kalendri»%s«.",
    "Open »%s«" : "Ava »%s«",
    "Cheers!" : "Tervist!",
    "Today" : "Täna",
    "Day" : "Päev",
    "Week" : "Nädal",
    "Month" : "Kuu",
    "Download" : "Lae alla",
    "Delete" : "Kustuta",
    "Share link" : "Jaga link",
    "Share with users or groups" : "Jaga kasutajate või gruppidega",
    "can edit" : "saab muuta",
    "New calendar" : "Uus kalender",
    "Filename" : "Faili nimi",
    "Cancel" : "Loobu",
    "Automatic" : "Automaatne",
    "Show week numbers" : "Näita nädalanumberid",
    "Settings & import" : "Sätted & importimine",
    "Email" : "Epost",
    "Unknown" : "Teadmata",
    "All day" : "Kogu päev",
    "from" : "alates",
    "to" : "kuni",
    "never" : "mitte kunagi",
    "after" : "pärast",
    "Repeat" : "Korda",
    "Monday" : "Esmaspäev",
    "Summary" : "Kokkuvõte",
    "More" : "Rohkem",
    "Save" : "Salvesta",
    "Update" : "Uuenda",
    "Personal" : "Isiklik",
    "Details" : "Üksikasjad",
    "Attendees" : "Osalejad",
    "Reminders" : "Meelespead",
    "Activity" : "Tegevus",
    "Close" : "Sulge",
    "Anniversary" : "Aastapäev",
    "Week {number} of {year}" : "Nädal nr. {number} aastas {year}",
    "Daily" : "Iga päev",
    "Weekly" : "Iga nädal",
    "When shared show full event" : "Kui on jagatud, siis näita kogu sündmust",
    "When shared show only busy" : "Kui on jagatud, siis näita ainult, kas on hõivatud",
    "When shared hide this event" : "Kui on jagatud, siis peida see sündmus",
    "Location" : "Asukoht",
    "Description" : "Kirjeldus",
    "Status" : "Staatus",
    "Confirmed" : "Kinnitatud",
    "Tentative" : "Esialgne",
    "Cancelled" : "Tühistatud",
    "Categories" : "Kategooriad",
    "Office" : "Kontor",
    "Mail" : "Kirjad",
    "Play" : "Esita",
    "Global" : "Üldine"
},
"nplurals=2; plural=(n != 1);");
